@@ -39,18 +39,15 @@
 #include <QLineEdit>
 #include <QMenu>
 #include <QMenuBar>
-#include <QToolBar>
 #include <QQuickWidget>
 
 // KDE includes
-#include <KToolBarSpacerAction>
 #include <KActionCollection>
 #include <kdeclarative/kdeclarative.h>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KToolBar>
 #include <KXMLGUIFactory>
-#include <KToolBarPopupAction>
 #include <KIO/MetaData>
 #include <KHelpMenu>
 #include <KAboutData>
@@ -58,10 +55,11 @@
 // Libmuon includes
 #include <libmuon/MuonDataSources.h>
 #include <resources/ResourcesModel.h>
+#include <resources/UIHelper.h>
 #include <Category/Category.h>
 
 MuonDiscoverMainWindow::MuonDiscoverMainWindow()
-    : MuonMainWindow()
+    : KXmlGuiWindow()
 {
     initialize();
     //TODO: reconsider for QtQuick2
@@ -83,10 +81,6 @@ MuonDiscoverMainWindow::MuonDiscoverMainWindow()
     qmlRegisterType<QActionGroup>();
     qmlRegisterType<QAction>();
     
-    m_searchText = new QLineEdit(this);
-    m_searchText->setPlaceholderText(i18n("Search..."));
-    
-    actionCollection()->addAction("edit_find", KStandardAction::find(m_searchText, SLOT(setFocus()), this));
     //Here we set up a cache for the screenshots
     engine->rootContext()->setContextProperty("app", this);
 //
@@ -114,12 +108,6 @@ MuonDiscoverMainWindow::MuonDiscoverMainWindow()
     setupActions();
 }
 
-void MuonDiscoverMainWindow::showEvent(QShowEvent* ev)
-{
-    QWidget::showEvent(ev);
-    m_searchText->setFocus();
-}
-
 void MuonDiscoverMainWindow::initialize()
 {
     ResourcesModel *m = ResourcesModel::global();
@@ -218,39 +206,25 @@ QUrl MuonDiscoverMainWindow::prioritaryFeaturedSource() const
 void MuonDiscoverMainWindow::setupActions()
 {
     setupGUI(StandardWindowOption(KXmlGuiWindow::Default & ~KXmlGuiWindow::StatusBar & ~KXmlGuiWindow::ToolBar));
-    MuonMainWindow::setupActions();
+
+    QAction *quitAction = KStandardAction::quit(QCoreApplication::instance(), SLOT(quit()), actionCollection());
+    actionCollection()->addAction("file_quit", quitAction);
 
     menuBar()->setVisible(false);
+    toolBar("discoverToolBar")->setVisible(false);
 
-    QToolBar* t = toolBar("discoverToolBar");
     m_moreMenu = new QMenu(this);
     m_advancedMenu = new QMenu(i18n("Advanced..."), m_moreMenu);
     configureMenu();
-    t->setVisible(true);
-    
-    KToolBarPopupAction* configureButton = new KToolBarPopupAction(QIcon::fromTheme("applications-system"), i18n("Menu"), t);
-    configureButton->setToolTip(i18n("Configure and learn about Muon Discover"));
-    configureButton->setMenu(m_moreMenu);
-    configureButton->setDelayed(false);
-    configureButton->setPriority(QAction::LowPriority);
-    
-    t->addAction(new KToolBarSpacerAction(t));
-    t->addWidget(m_searchText);
-    t->addAction(configureButton);
 
     connect(ResourcesModel::global(), &ResourcesModel::allInitialized, this, &MuonDiscoverMainWindow::configureMenu);
 }
 
-QObject* MuonDiscoverMainWindow::searchWidget() const
-{
-    return m_searchText;
-}
-
 void MuonDiscoverMainWindow::configureMenu()
 {
     m_advancedMenu->clear();
     m_moreMenu->clear();
-    setupMessageActions(m_moreMenu, m_advancedMenu, ResourcesModel::global()->messageActions());
+    UIHelper::setupMessageActions(m_moreMenu, m_advancedMenu, ResourcesModel::global()->messageActions());
 
     if (!m_moreMenu->isEmpty())
         m_moreMenu->addSeparator();
@@ -263,3 +237,14 @@ void MuonDiscoverMainWindow::configureMenu()
     m_moreMenu->addAction(actionCollection()->action("help_about_kde"));
     m_moreMenu->addAction(actionCollection()->action("help_report_bug"));
 }
+
+bool MuonDiscoverMainWindow::queryClose()
+{
+    return !ResourcesModel::global()->isBusy();
+}
+
+void MuonDiscoverMainWindow::showMenu(int x, int y)
+{
+    QPoint p = m_view->mapToGlobal(QPoint(x, y));
+    m_moreMenu->exec(p);
+}
