@@ -22,7 +22,7 @@
 
 #include <QtCore/QUrl>
 
-#include "MuonMainWindow.h"
+#include <KXmlGuiWindow>
 
 class QQmlEngine;
 class QLineEdit;
@@ -31,23 +31,21 @@ class AbstractResource;
 class Category;
 class QQuickWidget;
 
-class MuonDiscoverMainWindow : public MuonMainWindow
+class MuonDiscoverMainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
-    Q_PROPERTY(QObject* searchWidget READ searchWidget CONSTANT)
     public:
         explicit MuonDiscoverMainWindow();
         ~MuonDiscoverMainWindow();
 
         Q_SCRIPTABLE QAction* getAction(const QString& name);
-        QSize sizeHint() const;
+        QSize sizeHint() const override;
         
         void initialize();
         QStringList modes() const;
         void setupActions();
-        QObject* searchWidget() const;
 
-        virtual void showEvent(QShowEvent*);
+        bool queryClose() Q_DECL_OVERRIDE;
 
     public slots:
         void openApplication(const QString& app);
@@ -56,6 +54,7 @@ class MuonDiscoverMainWindow : public MuonMainWindow
         void openMimeType(const QString& mime);
         void openCategory(const QString& category);
         void openMode(const QByteArray& mode);
+        void showMenu(int x, int y);
 
     private slots:
         void triggerOpenApplication();
@@ -69,7 +68,6 @@ class MuonDiscoverMainWindow : public MuonMainWindow
         void configureMenu();
 
         QString m_appToBeOpened;
-        QLineEdit* m_searchText;
         QQuickWidget* m_view;
         QMenu* m_moreMenu;
         QMenu* m_advancedMenu;
