@@ -32,6 +32,7 @@
 #include <QStandardPaths>
 #include <QDialogButtonBox>
 #include <QLayout>
+#include <QNetworkConfigurationManager>
 
 // KDE includes
 #include <KActionCollection>
@@ -43,16 +44,12 @@
 #include <KSharedConfig>
 #include <KXmlGuiWindow>
 #include <KWindowConfig>
-// #include <Solid/Networking>
 
 // QApt includes
 #include <QApt/Backend>
 #include <QApt/DebFile>
 #include <QApt/Transaction>
 
-// Own includes
-#include "MuonMainWindow.h"
-
 QAptActions::QAptActions()
     : QObject(nullptr)
     , m_backend(nullptr)
@@ -61,10 +58,9 @@ QAptActions::QAptActions()
     , m_reloadWhenEditorFinished(false)
     , m_historyDialog(nullptr)
     , m_distUpgradeAvailable(false)
+    , m_config(new QNetworkConfigurationManager(this))
 {
-//     TODO: port to kf5
-//     connect(Solid::Networking::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)),
-//             this, SLOT(networkChanged()));
+    connect(m_config, &QNetworkConfigurationManager::onlineStateChanged, this, &QAptActions::shouldConnect);
 }
 
 QAptActions* QAptActions::self()
@@ -76,15 +72,15 @@ QAptActions* QAptActions::self()
     return self;
 }
 
-void QAptActions::setMainWindow(MuonMainWindow* w)
+void QAptActions::setMainWindow(KXmlGuiWindow* w)
 {
     setParent(w);
     m_mainWindow = w;
-    connect(m_mainWindow, SIGNAL(actionsEnabledChanged(bool)), SLOT(setActionsEnabledInternal(bool)));
+
     setupActions();
 }
 
-MuonMainWindow* QAptActions::mainWindow() const
+KXmlGuiWindow* QAptActions::mainWindow() const
 {
     return m_mainWindow;
 }
@@ -154,9 +150,7 @@ void QAptActions::setupActions()
     downloadListAction->setIcon(QIcon::fromTheme("download"));
     downloadListAction->setText(i18nc("@action", "Download Packages From List..."));
     connect(downloadListAction, SIGNAL(triggered()), this, SLOT(downloadPackagesFromList()));
-    if (!isConnected()) {
-        downloadListAction->setDisabled(false);
-    }
+    downloadListAction->setEnabled(isConnected());
     connect(this, SIGNAL(shouldConnect(bool)), downloadListAction, SLOT(setEnabled(bool)));
     m_actions.append(downloadListAction);
 
@@ -192,7 +186,7 @@ void QAptActions::setupActions()
     m_actions.append(saveInstalledAction);
 }
 
-void QAptActions::setActionsEnabledInternal(bool enabled)
+void QAptActions::setActionsEnabled(bool enabled)
 {
     m_actionsDisabled = !enabled;
 
@@ -200,7 +194,7 @@ void QAptActions::setActionsEnabledInternal(bool enabled)
         action->setEnabled(enabled);
     }
 
-    if (!enabled)
+    if (!enabled || !m_mainWindow || !actionCollection())
         return;
 
     actionCollection()->action("update")->setEnabled(isConnected() && enabled);
@@ -222,21 +216,9 @@ bool QAptActions::reloadWhenSourcesEditorFinished() const
     return m_reloadWhenEditorFinished;
 }
 
-bool QAptActions::isConnected() const {
-//     int status = Solid::Networking::status();
-//     bool connected = ((status == Solid::Networking::Connected) ||
-//                       (status == Solid::Networking::Unknown));
-//     return connected;
-//     TODO: port to kf5
-    return true;
-}
-
-void QAptActions::networkChanged()
+bool QAptActions::isConnected() const
 {
-    if (m_actionsDisabled)
-        return;
-
-    emit shouldConnect(isConnected());
+    return m_config->isOnline();
 }
 
 bool QAptActions::saveSelections()
@@ -407,7 +389,7 @@ void QAptActions::runSourcesEditor()
     QStringList arguments;
     int winID = m_mainWindow->effectiveWinId();
 
-    QString kdesudo = QStandardPaths::findExecutable("kdesudo");
+    QString pkexec = QStandardPaths::findExecutable("pkexec");
     QString editor = QStandardPaths::findExecutable("software-properties-kde");
 
     if (m_reloadWhenEditorFinished) {
@@ -416,7 +398,7 @@ void QAptActions::runSourcesEditor()
         editor.append(QLatin1String(" --attach ") % QString::number(winID));
     }
 
-    arguments << kdesudo << editor;
+    arguments << pkexec << editor;
 
     proc->setProgram(arguments);
     m_mainWindow->find(winID)->setEnabled(false);
@@ -522,30 +504,24 @@ void QAptActions::closeHistoryDialog()
     m_historyDialog = nullptr;
 }
 
-void QAptActions::setActionsEnabled(bool enabled)
-{
-    if(m_mainWindow)
-        m_mainWindow->setActionsEnabled(enabled);
-    else
-        setActionsEnabledInternal(enabled);
-}
-
 void QAptActions::launchDistUpgrade()
 {
-    QString kdesudo = QStandardPaths::findExecutable("kdesudo");
+    QString pkexec = QStandardPaths::findExecutable("pkexec");
     QString upgrader = QStringLiteral("do-release-upgrade -m desktop -f DistUpgradeViewKDE");
 
-    QProcess::startDetached(kdesudo, QStringList() << upgrader);
+    QProcess::startDetached(pkexec, QStringList() << upgrader);
 }
 
 void QAptActions::checkDistUpgrade()
 {
     if(!QFile::exists("/usr/lib/python3/dist-packages/DistUpgrade/DistUpgradeFetcherKDE.py")) {
         qWarning() << "Couldn't find the /usr/lib/python3/dist-packages/DistUpgrade/DistUpgradeFetcherKDE.py file";
+        return;
     }
     QString checkerFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libmuon/applicationsbackend/releasechecker");
     if(checkerFile.isEmpty()) {
         qWarning() << "Couldn't find the releasechecker script" << QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+        return;
     }
 
     KProcess* checkerProcess = new KProcess(this);
@@ -557,6 +533,8 @@ void QAptActions::checkDistUpgrade()
 
 void QAptActions::checkerFinished(int res)
 {
-    m_distUpgradeAvailable = res == 0;
-    QAptActions::self()->actionCollection()->action("dist-upgrade")->setEnabled(res == 0);
+    m_distUpgradeAvailable = (res == 0);
+    if (!m_mainWindow)
+        return;
+    actionCollection()->action("dist-upgrade")->setEnabled(m_distUpgradeAvailable);
 }
