@@ -56,10 +56,11 @@
 #include "../libmuonapt/QAptActions.h"
 
 MainWindow::MainWindow()
-    : MuonMainWindow()
+    : KXmlGuiWindow()
     , m_settingsDialog(nullptr)
     , m_reviewWidget(nullptr)
     , m_transWidget(nullptr)
+    , m_reloading(false)
 
 {
     initGUI();
@@ -92,8 +93,6 @@ void MainWindow::initGUI()
     m_mainWidget = new QSplitter(this);
     m_mainWidget->setOrientation(Qt::Horizontal);
     connect(m_mainWidget, SIGNAL(splitterMoved(int,int)), this, SLOT(saveSplitterSizes()));
-    connect(m_managerWidget, SIGNAL(doneSortingPackages(bool)),
-            this, SLOT(setCanExit(bool)));
 
     m_transWidget = new TransactionWidget(this);
 
@@ -170,7 +169,8 @@ void MainWindow::saveSplitterSizes()
 
 void MainWindow::setupActions()
 {
-    MuonMainWindow::setupActions();
+    QAction *quitAction = KStandardAction::quit(QCoreApplication::instance(), SLOT(quit()), actionCollection());
+    actionCollection()->addAction("file_quit", quitAction);
 
     m_safeUpgradeAction = actionCollection()->addAction("safeupgrade");
     m_safeUpgradeAction->setIcon(QIcon::fromTheme("go-up"));
@@ -204,10 +204,8 @@ void MainWindow::setupActions()
     updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
     actionCollection()->setDefaultShortcut(updateAction, QKeySequence(Qt::CTRL + Qt::Key_R));
     connect(updateAction, SIGNAL(triggered()), SLOT(checkForUpdates()));
-    if (!isConnected()) {
-        updateAction->setDisabled(true);
-    }
-    connect(this, SIGNAL(shouldConnect(bool)), updateAction, SLOT(setEnabled(bool)));
+    updateAction->setEnabled(QAptActions::self()->isConnected());
+    connect(QAptActions::self(), SIGNAL(shouldConnect(bool)), updateAction, SLOT(setEnabled(bool)));
 
     KStandardAction::preferences(this, SLOT(editSettings()), actionCollection());
 
@@ -347,9 +345,14 @@ void MainWindow::startCommit()
     m_trans->run();
 }
 
+bool MainWindow::queryClose()
+{
+    return !m_reloading && !m_managerWidget->isSortingPackages() && QAptActions::self()->canExit();
+}
+
 void MainWindow::reload()
 {
-    setCanExit(false);
+    m_reloading = true;
     returnFromPreview();
     m_stack->setCurrentWidget(m_mainWidget);
 
@@ -368,12 +371,12 @@ void MainWindow::reload()
     setActionsEnabled();
     m_managerWidget->setEnabled(true);
 
-    setCanExit(true);
+    m_reloading = false;
 }
 
 void MainWindow::setActionsEnabled(bool enabled)
 {
-    MuonMainWindow::setActionsEnabled(enabled);
+    QAptActions::self()->setActionsEnabled(enabled);
     if (!enabled) {
         m_applyAction->setEnabled(false);
         m_safeUpgradeAction->setEnabled(false);
@@ -455,3 +458,8 @@ void MainWindow::setupTransaction(QApt::Transaction *trans)
     connect(m_trans, SIGNAL(errorOccurred(QApt::ErrorCode)),
             this, SLOT(errorOccurred(QApt::ErrorCode)));
 }
+
+QSize MainWindow::sizeHint() const
+{
+    return KXmlGuiWindow::sizeHint().expandedTo(QSize(900, 500));
+}
